pub struct Tag(pub [u8; 32]);Expand description
A pseudorandom tag that acts as the address of one entry in the server EDB.
Derived as: tag = PRF(K_tag, “tag:” || keyword || index || epoch)
To the server this is indistinguishable from random bytes — it reveals nothing about the keyword, document, or time of write.
Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Tag
impl<'de> Deserialize<'de> for Tag
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Tag
impl StructuralPartialEq for Tag